@@ -15,11 +15,9 @@
 #include <qlabel.h>
 #include <qheaderview.h>
 #include <qtextedit.h>
-#include <kcolorbutton.h>
 #include <kicon.h>
 #include <klineedit.h>
 #include <klocale.h>
-#include <knuminput.h>
 #include <kglobal.h>
 
 // local includes
@@ -54,55 +52,28 @@ AnnotsPropertiesDialog::AnnotsPropertiesDialog( QWidget *parent, Okular::Documen
     QLabel* tmplabel;
   //1. Appearance
     //BEGIN tab1
-    QFrame *page = new QFrame( this );
-    addPage( page, i18n( "&Appearance" ) );
-    QGridLayout * gridlayout = new QGridLayout( page );
-
-    tmplabel = new QLabel( i18n( "&Color:" ), page );
-    gridlayout->addWidget( tmplabel, 0, 0, Qt::AlignRight );
-    colorBn = new KColorButton( page );
-    colorBn->setColor( ann->style().color() );
-    colorBn->setEnabled( canEditAnnotations );
-    tmplabel->setBuddy( colorBn );
-    gridlayout->addWidget( colorBn, 0, 1 );
-
-    tmplabel = new QLabel( i18n( "&Opacity:" ), page );
-    gridlayout->addWidget( tmplabel, 1, 0, Qt::AlignRight );
-    m_opacity = new KIntNumInput( page );
-    m_opacity->setRange( 0, 100 );
-    m_opacity->setValue( (int)( ann->style().opacity() * 100 ) );
-    m_opacity->setSuffix( i18nc( "Suffix for the opacity level, eg '80 %'", " %" ) );
-    m_opacity->setEnabled( canEditAnnotations );
-    tmplabel->setBuddy( m_opacity );
-    gridlayout->addWidget( m_opacity, 1, 1 );
-
-    QWidget * configWidget = 0;
-    if ( m_annotWidget && ( configWidget = m_annotWidget->styleWidget() ) )
-    {
-        gridlayout->addWidget( configWidget, 2, 0, 1, 2 );
-        configWidget->setEnabled( canEditAnnotations );
-    }
-
-    gridlayout->addItem( new QSpacerItem( 5, 5, QSizePolicy::Fixed, QSizePolicy::MinimumExpanding ), 3, 0 );
+    QWidget *appearanceWidget = m_annotWidget->appearanceWidget();
+    appearanceWidget->setEnabled( canEditAnnotations );
+    addPage( appearanceWidget, i18n( "&Appearance" ) );
     //END tab1
-    
+
     //BEGIN tab 2
-    page = new QFrame( this );
+    QFrame* page = new QFrame( this );
     addPage( page, i18n( "&General" ) );
 //    m_tabitem[1]->setIcon( KIcon( "fonts" ) );
-    gridlayout = new QGridLayout( page );
+    QGridLayout* gridlayout = new QGridLayout( page );
     tmplabel = new QLabel( i18n( "&Author:" ), page );
     AuthorEdit = new KLineEdit( ann->author(), page );
     AuthorEdit->setEnabled( canEditAnnotations );
     tmplabel->setBuddy( AuthorEdit );
     gridlayout->addWidget( tmplabel, 0, 0, Qt::AlignRight );
     gridlayout->addWidget( AuthorEdit, 0, 1 );
-    
+
     tmplabel = new QLabel( page );
     tmplabel->setText( i18n( "Created: %1", KGlobal::locale()->formatDateTime( ann->creationDate(), KLocale::LongDate, true ) ) );
     tmplabel->setTextInteractionFlags( Qt::TextSelectableByMouse );
     gridlayout->addWidget( tmplabel, 1, 0, 1, 2 );
-    
+
     m_modifyDateLabel = new QLabel( page );
     m_modifyDateLabel->setText( i18n( "Modified: %1", KGlobal::locale()->formatDateTime( ann->modificationDate(), KLocale::LongDate, true ) ) );
     m_modifyDateLabel->setTextInteractionFlags( Qt::TextSelectableByMouse );
@@ -111,20 +82,15 @@ AnnotsPropertiesDialog::AnnotsPropertiesDialog( QWidget *parent, Okular::Documen
     gridlayout->addItem( new QSpacerItem( 5, 5, QSizePolicy::Fixed, QSizePolicy::MinimumExpanding ), 3, 0 );
     //END tab 2
 
-    QWidget * extraWidget = 0;
-    if ( m_annotWidget && ( extraWidget = m_annotWidget->extraWidget() ) )
+    QWidget * extraWidget = m_annotWidget->extraWidget();
+    if ( extraWidget )
     {
         addPage( extraWidget, extraWidget->windowTitle() );
     }
 
     //BEGIN connections
-    connect( colorBn, SIGNAL(changed(QColor)), this, SLOT(setModified()) );
-    connect( m_opacity, SIGNAL(valueChanged(int)), this, SLOT(setModified()) );
     connect( AuthorEdit, SIGNAL(textChanged(QString)), this, SLOT(setModified()) );
-    if ( m_annotWidget )
-    {
-        connect( m_annotWidget, SIGNAL(dataChanged()), this, SLOT(setModified()) );
-    }
+    connect( m_annotWidget, SIGNAL(dataChanged()), this, SLOT(setModified()) );
     //END
 
 #if 0
@@ -149,24 +115,27 @@ void AnnotsPropertiesDialog::setCaptionTextbyAnnotType()
     {
         case Okular::Annotation::AText:
             if(((Okular::TextAnnotation*)m_annot)->textType()==Okular::TextAnnotation::Linked)
-                captiontext = i18n( "Note Properties" );
+                captiontext = i18n( "Pop-up Note Properties" );
             else
                 captiontext = i18n( "Inline Note Properties" );
             break;
         case Okular::Annotation::ALine:
-            captiontext = i18n( "Line Properties" );
+            if ( ((Okular::LineAnnotation*)m_annot)->linePoints().count() == 2 )
+                captiontext = i18n( "Straight Line Properties" );
+            else
+                captiontext = i18n( "Polygon Properties" );
             break;
         case Okular::Annotation::AGeom:
             captiontext = i18n( "Geometry Properties" );
             break;
         case Okular::Annotation::AHighlight:
-            captiontext = i18n( "Highlight Properties" );
+            captiontext = i18n( "Text Markup Properties" );
             break;
         case Okular::Annotation::AStamp:
             captiontext = i18n( "Stamp Properties" );
             break;
         case Okular::Annotation::AInk:
-            captiontext = i18n( "Ink Properties" );
+            captiontext = i18n( "Freehand Line Properties" );
             break;
         case Okular::Annotation::ACaret:
             captiontext = i18n( "Caret Properties" );
@@ -198,15 +167,13 @@ void AnnotsPropertiesDialog::slotapply()
     if ( !modified )
         return;
 
+    m_document->prepareToModifyAnnotationProperties( m_annot );
     m_annot->setAuthor( AuthorEdit->text() );
     m_annot->setModificationDate( QDateTime::currentDateTime() );
-    m_annot->style().setColor( colorBn->color() );
-    m_annot->style().setOpacity( (double)m_opacity->value() / 100.0 );
 
-    if ( m_annotWidget )
-        m_annotWidget->applyChanges();
+    m_annotWidget->applyChanges();
 
-    m_document->modifyPageAnnotation( m_page, m_annot );
+    m_document->modifyPageAnnotationProperties( m_page, m_annot );
 
     m_modifyDateLabel->setText( i18n( "Modified: %1", KGlobal::locale()->formatDateTime( m_annot->modificationDate(), KLocale::LongDate, true ) ) );
 
@@ -215,4 +182,4 @@ void AnnotsPropertiesDialog::slotapply()
 }
 
 #include "annotationpropertiesdialog.moc"
-    
+
